==> apache-seatunnel-2.3.9-src.tar.gz: apache-seatunnel-2.3.9-src/seatunnel-connectors-v2/connector-typesense/src/main/java/org/apache/seatunnel/connectors/seatunnel/typesense/dto/CollectionInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.typesense.dto;

import org.apache.seatunnel.api.configuration.ReadonlyConfig;
import org.apache.seatunnel.connectors.seatunnel.typesense.config.SinkConfig;

import lombok.Data;

@Data
public class CollectionInfo {

    private String collection;
    private String type;
    private String[] primaryKeys;
    private String keyDelimiter;

    public CollectionInfo(String collection, ReadonlyConfig config) {
        this.collection = collection;
        if (config.getOptional(SinkConfig.PRIMARY_KEYS).isPresent()) {
            primaryKeys = config.get(SinkConfig.PRIMARY_KEYS).toArray(new String[0]);
        }
        keyDelimiter = config.get(SinkConfig.KEY_DELIMITER);
    }
}

==> apache-seatunnel-2.3.12-src.tar.gz: apache-seatunnel-2.3.12-src/seatunnel-connectors-v2/connector-typesense/src/main/java/org/apache/seatunnel/connectors/seatunnel/typesense/dto/CollectionInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.typesense.dto;

import org.apache.seatunnel.api.configuration.ReadonlyConfig;
import org.apache.seatunnel.connectors.seatunnel.typesense.config.TypesenseSinkOptions;

import lombok.Data;

@Data
public class CollectionInfo {

    private String collection;
    private String type;
    private String[] primaryKeys;
    private String keyDelimiter;

    public CollectionInfo(String collection, ReadonlyConfig config) {
        this.collection = collection;
        if (config.getOptional(TypesenseSinkOptions.PRIMARY_KEYS).isPresent()) {
            primaryKeys = config.get(TypesenseSinkOptions.PRIMARY_KEYS).toArray(new String[0]);
        }
        keyDelimiter = config.get(TypesenseSinkOptions.KEY_DELIMITER);
    }
}
